/***********************************************************************************
FILE NAME       HWInit.c

DESCRIPTION     Functions that are required to setup the hardware correclty on
                each board

Copyright:      2006 Renesas Technology Corporation.
                All Rights Reserved
***********************************************************************************/
#include "AudioInfo.h"

/*****************************************************************************
Name:        InitTimer
Parameters:  none
Returns:     none
Description: Sets timer to default for sound data output timing generation.
             Uses TimerRB timer.
*****************************************************************************/
void InitTimer( void )
{
    
  /* start time */
  tb1mr    = 0x00;            /* timer mode, count source:f1 */
  tb1      = 1814-1;          /* 90.7us cycle(for 11Khz sampling) @20MHz f1 */
  ir_tb1ic = 0;               /* interrupt request bit clear */
  tb1ic    = TIMER_IPL;          /* set interrupt priority level */
  tb1s     = 1;               /* start count */
}

/*****************************************************************************
Name:        InitPWM
Parameters:  none
Returns:     none
Description: Initialization of a PWM output
*****************************************************************************/
void InitPWM( void )
{
    ta3mr = 0x27;   /* pulse modulation MODE, 8bit pulse modulation, count source f1 */
    ta3ic = 0;      /* clear TA3 interrupt request bit */
    ta3   = AUDIO_PWM_SILENCE; /* default count: upper 8bit(sound data: 0), lower8bit(0) */
    ta3s  = 1;      /* start TA3 count */

    ta2mr = 0x27;   /* pulse modulation MODE, 8bit pulse modulation, count source f1 */
    ta2ic = 0;      /* clear TA3 interrupt request bit */
    ta2   = AUDIO_PWM_SILENCE; /* default count: upper 8bit(sound data: 0), lower8bit(0) */
    ta2s  = 1;      /* start TA3 count */
        
}

/*****************************************************************************
Name:        InitAD
Parameters:  none
Returns:     none
Description: Initialization of a AD converter on AN1
*****************************************************************************/
void InitAD( void )
{
//    adcon0 = 0x09;      /* sw trigger, repeat mode, AN1 */       //	THIS IS ORIGINAL FOR CDS  
//	  adcon1 = 0x20;      /* vref connected, 8 bit mode */
//    adcon2 = 0x01;      /* P10 group, sample and hold */

    adcon0 = 0x09;      /* sw trigger, repeat mode, AN1 */       //// THIS IS ADDED BY ABOHMEED FOR AN4
	adcon1 = 0x20;      /* vref connected, 8 bit mode */
    adcon2 = 0x01;      /* P10 group, sample and hold */

/// NOTE FOR ABOHMEED : TO SELECT CHANNEL AN4 , JUST ASSIGN acdon0 TO 0C   (  AND FOR AN5 0D )  ;)

    
    adst = 1;           /* start conversion */
}

/*****************************************************************************
Name:        InitAudio
Parameters:  none
Returns:     none
Description: Sets up the SPB board to playback audio.
*****************************************************************************/
void InitAudio( void )
{
    InitPWM();
    InitTimer();
}

/***********************************************************************************
Function Name: 	PortInit
Description:	Configures IO ports
Parameters:     none
Return value:   none
***********************************************************************************/
void PortInit(void)
{ 
    /* configure ports */
    p1 = 0x00;
    pd1 = 0xE0;
    p6 &= 0xF0;
    pd6 |= 0x0F;
    //p7 = 0x55;
    pd7 = 0xFF;
    p8 = 0x00;
    pd8 = 0x3F;
    p9 = 0x00;
    prc2 = 1;
    pd9 = 0x0E;
    pd10 = 0;
}

/***********************************************************************************
Function Name: 	InitCLOCK
Description:	Sets up the system clocks
Parameters: none
Return value: none
***********************************************************************************/
void InitCLOCK( void )
{
    HardwareSetup();
    
    pd8_6 = 0;
    pd8_7 = 0;
    prc0 = 1;
    cm04  = 1;              /* enable sub-clock */
    prc0 = 0;
}

/***********************************************************************************
Function Name: 	InitCLOCK
Description:	Sets up the sub clock
Parameters:     none
Return value:   none
***********************************************************************************/
void InitSubClockTest( void )
{   
    /* start tb0 running from fc32 */
    tb0s = 0;           /* stop clock */
    ir_tb0ic = 0;       /* clear any pending interrupts */
    tb0mr = 0xC0;       /* timer mode using fc32 */
    tb0 = 1024;   /* set rate to 4/second */
    tb0s = 1;           /* start clock */ 
    
    /*
      this tests to make sure the 32khz clock is running, if it is not running
      then this flag will never get set 
    */
    while(ir_tb0ic == 0);   
}

/*****************************************************************************
Name:           TestADC
Parameters:     none
Returns:        none
Description:    Toggle leds based on AD conversion.
*****************************************************************************/
void TestADC(void)
{
    if(ir_tb0ic == 1)
    {   
        ir_tb0ic = 0;
        
        tb0 = ad1 << 1;
        
        if(RED_LED == LED_ON)
        {
            RED_LED = LED_OFF;
            AMB_LED = LED_ON;
        } else
        {
            RED_LED = LED_ON;
            AMB_LED = LED_OFF;
        }
    }
}
